﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
    
// Дополнительные пространства имен
using System.Data.OleDb;
using System.Data.Common;
    
namespace WinForms7
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
    
            // Подписка на события ComboBox общего обработчика
            cbLetters.SelectedIndexChanged += Combo_SelectedIndexChanged;
            cbColumns.SelectedIndexChanged += Combo_SelectedIndexChanged;
    
            // Загрузки объектов данными
            LoadCustomers();
            LoadLetters();
            LoadColumns();// Вызывать после загрузки данных LoadCustomers()
        }
    
        // Строка соединения к БД с абсолютным путем, определяемым сборкой
        String ConnectionString()
        {
            // Используем построитель строки подключения 
            OleDbConnectionStringBuilder objConnectionStringBuilder =
                new OleDbConnectionStringBuilder();
            objConnectionStringBuilder.Provider = "Microsoft.Jet.OLEDB.4.0";
            objConnectionStringBuilder.DataSource =
                Application.StartupPath.ToString() + @"\Data\Northwind.mdb";
    
            return objConnectionStringBuilder.ToString();
        }
    
        DataTable tableCustomers;// Поле, видимое в методах
        void LoadCustomers()
        {
            // Формируем поставщик 
            OleDbCommand selectCommand = new OleDbCommand();
            selectCommand.CommandText =
                "SELECT * FROM Customers";// Будем читать все столбцы
            selectCommand.Connection = new OleDbConnection(ConnectionString());
            selectCommand.CommandType = CommandType.Text;// По умолчанию
            OleDbDataAdapter adapter = new OleDbDataAdapter(selectCommand);
    
            // Создаем объект таблицы
            tableCustomers = new DataTable();
    
            // Заполняем таблицу
            adapter.Fill(tableCustomers);
            // Адресуемся к встроенному в таблицу представлению
            DataView defaultView = tableCustomers.DefaultView;
    
            // Связываем встроенное представление с элементом отображения
            dataGrid.DataSource = defaultView;
        }
    
        void LoadLetters()
        {
            // Добавили первый элемент списка
            cbLetters.Items.Add("All");
    
            // Дополняем список буквами алфавита
            for (char ch = 'A'; ch <= 'Z'; ch++)
            {
                cbLetters.Items.Add(ch);
            }
    
            // Устанавливаем на первый индекс 
            cbLetters.SelectedIndex = 0;
        }
    
        void LoadColumns()
        {
            // Создаем временную таблицу для имен столбцов
            DataTable tableTmp = new DataTable();
            // Добавляем один столбец для хранения имен столбцов 
            tableTmp.Columns.Add("ColumnName", typeof(String));
            // Заполняем временную таблицу именами столбцов исходной таблицы
            for (int i = 0; i < tableCustomers.Columns.Count; i++)
            {
                tableTmp.Rows.Add(tableCustomers.Columns[i].ColumnName);
            }
            // Создаем представление по единственному столбцу
            DataView view = new DataView(tableTmp);
    
            // Связываем представление с элементом отображения
            cbColumns.DataSource = view;
            cbColumns.DisplayMember = "ColumnName";
    
            // Ищем нужное имя и позиционируем список
            view.Sort = "ColumnName";// Сортируем для списка имен столбцов
            int selectedIndex = view.Find("CustomerID");// По отсортированному можно
            cbColumns.SelectedIndex = selectedIndex;// Позиционируем программно на CustomerID
        }
    
        private void Combo_SelectedIndexChanged(object sender, EventArgs e)
        {
            // Еще не созданы
            if (cbLetters == null || cbColumns == null)
                return;
            // Еще ничего не выбрано
            if (cbLetters.SelectedIndex == -1 || cbColumns.SelectedIndex == -1)
                return;
    
            // Извлекаем символ из cbLetters
            String letter = cbLetters.SelectedItem.ToString();
            if (letter == "All")
                letter = String.Empty;
    
            // Извлекаем из cbColumns, связанного с DataView, выбранное имя столбца 
            Object obj = cbColumns.SelectedItem;
            String columnName = ((DataRowView)obj).Row["ColumnName"].ToString();
    
            // Создаем для таблицы Customers объект представления и настраиваем его
            DataView view = new DataView(tableCustomers);
            view.RowFilter = "CustomerID LIKE '" + letter + "%'";
            view.Sort = columnName;
    
            // Связываем настроенное представление с объектом отображения
            dataGrid.DataSource = view;
        }
    }
}